from __future__ import annotations

from .aggregated_tasks import *
from .BitextMining import *
from .Classification import *
from .Clustering import *
from .InstructionRetrieval import *
from .MultiLabelClassification import *
from .PairClassification import *
from .Reranking import *
from .Retrieval import *
from .SpeedTask import *
from .STS import *
from .Summarization import *
from .SummaryRetrieval import *
